maybe_resolve_ref

Function maybe_resolve_ref 

pub fn maybe_resolve_ref(refspec: &str, root: &Path) -> String
Try to resolve a ref string via jj if we’re in a jj repo. Falls back to the original string if not a jj repo or resolution fails.