pub struct IncrementalBuildMetadata {
pub repaired_clean_entity_ids: bool,
pub recomputed_edge_source_ids: Vec<String>,
pub deleted_entity_ids: Vec<String>,
}Expand description
Metadata describing repairs made during an incremental graph build.
Fields
repaired_clean_entity_ids: boolrecomputed_edge_source_ids: Vec<String>deleted_entity_ids: Vec<String>Trait Implementations
Sourceimpl Clone for IncrementalBuildMetadata
impl Clone for IncrementalBuildMetadata
Sourcefn clone(&self) -> IncrementalBuildMetadata
fn clone(&self) -> IncrementalBuildMetadata
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IncrementalBuildMetadata
impl Debug for IncrementalBuildMetadata
Sourceimpl Default for IncrementalBuildMetadata
impl Default for IncrementalBuildMetadata
Sourcefn default() -> IncrementalBuildMetadata
fn default() -> IncrementalBuildMetadata
Returns the “default value” for a type. Read more
impl Eq for IncrementalBuildMetadata
Sourceimpl PartialEq for IncrementalBuildMetadata
impl PartialEq for IncrementalBuildMetadata
Sourcefn eq(&self, other: &IncrementalBuildMetadata) -> bool
fn eq(&self, other: &IncrementalBuildMetadata) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for IncrementalBuildMetadata