Structs
- Assignment
Rule - A rule for scanning assignment nodes to extract type bindings.
- Import
Rule - Import node kind + extractor function pair
- Language
Config - Member
Access - How member access (obj.field / obj.method()) is represented in the AST.
- Param
Rule - A rule for extracting typed parameters from function signatures.
- Scope
Resolve Config - Configuration for scope-aware reference resolution. Captures the AST node names and strategies that differ per language.
- Suppressed
Nested Entity
Enums
- Assignment
Strategy - Strategy for extracting variable name and type from an assignment node.
- Call
Node Style - How call nodes expose the callee/function.
- Class
Name Field - How to extract the class/struct name from a scope node.
- Init
Strategy - Strategy for extracting instance attribute types from class definitions.
- Param
Name Field - How to extract the parameter name.
Functions
Type Aliases
- Import
Extractor Fn - Function pointer type for import extraction.