Functions
- is_
jj_ repo - Check if the given repo root is a Jujutsu repository.
- maybe_
resolve_ ref - Try to resolve a ref string via jj if we’re in a jj repo. Falls back to the original string if not a jj repo or resolution fails.
- resolve_
jj_ revset - Resolve a jj revset to a git commit SHA using
jj log. Returns None if jj is not installed, the revset is invalid, or resolution fails.