Skip to main contentModule parser
Source - context
- Context budgeting: pack optimal entity context into a token budget.
Priority: target entity > direct dependencies > direct dependents > transitive dependencies >
transitive dependents.
- differ
- graph
- Entity dependency graph — cross-file reference extraction.
- hotspot
- Hotspot analysis: find entities that change most frequently across git history.
High-churn entities are statistically more likely to contain bugs.
- plugin
- plugins
- registry
- scope_resolve
- Scope-aware reference resolver using tree-sitter ASTs.
- test_detect
- Shared test-path detection logic.
- js_ts_import_source_files_from_content