pub struct LanguageConfig {
pub id: &'static str,
pub extensions: &'static [&'static str],
pub entity_node_types: &'static [&'static str],
pub container_node_types: &'static [&'static str],
pub call_entity_identifiers: &'static [&'static str],
pub suppressed_nested_entities: &'static [SuppressedNestedEntity],
pub scope_boundary_types: &'static [&'static str],
pub get_language: fn() -> Option<Language>,
}Fields
id: &'static strextensions: &'static [&'static str]entity_node_types: &'static [&'static str]container_node_types: &'static [&'static str]call_entity_identifiers: &'static [&'static str]suppressed_nested_entities: &'static [SuppressedNestedEntity]scope_boundary_types: &'static [&'static str]Node types that introduce a new scope. The general (non-container) recursion in visit_node will not descend into these nodes, preventing local variables inside function bodies from being extracted as top-level entities.
get_language: fn() -> Option<Language>Auto Trait Implementations
impl Freeze for LanguageConfig
impl RefUnwindSafe for LanguageConfig
impl Send for LanguageConfig
impl Sync for LanguageConfig
impl Unpin for LanguageConfig
impl UnsafeUnpin for LanguageConfig
impl UnwindSafe for LanguageConfig